@@ -26,6 +26,35 @@ class CkafkaClient(AbstractClient):
     _service = 'ckafka'
 
 
+    def AuthorizeToken(self, request):
+        """给实例授权token
+
+        :param request: Request instance for AuthorizeToken.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.AuthorizeTokenRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.AuthorizeTokenResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("AuthorizeToken", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.AuthorizeTokenResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def BatchCreateAcl(self, request):
         """批量添加ACL策略
 
@@ -36,7 +65,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("BatchCreateAcl", params)
+            headers = request.headers
+            body = self.call("BatchCreateAcl", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.BatchCreateAclResponse()
@@ -64,7 +94,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("BatchModifyGroupOffsets", params)
+            headers = request.headers
+            body = self.call("BatchModifyGroupOffsets", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.BatchModifyGroupOffsetsResponse()
@@ -92,7 +123,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("BatchModifyTopicAttributes", params)
+            headers = request.headers
+            body = self.call("BatchModifyTopicAttributes", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.BatchModifyTopicAttributesResponse()
@@ -110,6 +142,35 @@ class CkafkaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CancelAuthorizationToken(self, request):
+        """取消授权token
+
+        :param request: Request instance for CancelAuthorizationToken.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.CancelAuthorizationTokenRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.CancelAuthorizationTokenResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CancelAuthorizationToken", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CancelAuthorizationTokenResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateAcl(self, request):
         """添加 ACL 策略
 
@@ -120,7 +181,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateAcl", params)
+            headers = request.headers
+            body = self.call("CreateAcl", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateAclResponse()
@@ -138,6 +200,35 @@ class CkafkaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateConsumer(self, request):
+        """创建消费者组
+
+        :param request: Request instance for CreateConsumer.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.CreateConsumerRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.CreateConsumerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateConsumer", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateConsumerResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateInstancePre(self, request):
         """创建实例(预付费包年包月)
 
@@ -148,7 +239,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateInstancePre", params)
+            headers = request.headers
+            body = self.call("CreateInstancePre", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateInstancePreResponse()
@@ -176,7 +268,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreatePartition", params)
+            headers = request.headers
+            body = self.call("CreatePartition", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreatePartitionResponse()
@@ -194,6 +287,64 @@ class CkafkaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateRoute(self, request):
+        """添加实例路由
+
+        :param request: Request instance for CreateRoute.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.CreateRouteRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.CreateRouteResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateRoute", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateRouteResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def CreateToken(self, request):
+        """创建最高权限的token
+
+        :param request: Request instance for CreateToken.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.CreateTokenRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.CreateTokenResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateToken", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateTokenResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateTopic(self, request):
         """创建ckafka主题
 
@@ -204,7 +355,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateTopic", params)
+            headers = request.headers
+            body = self.call("CreateTopic", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateTopicResponse()
@@ -232,7 +384,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateTopicIpWhiteList", params)
+            headers = request.headers
+            body = self.call("CreateTopicIpWhiteList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateTopicIpWhiteListResponse()
@@ -260,7 +413,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateUser", params)
+            headers = request.headers
+            body = self.call("CreateUser", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateUserResponse()
@@ -288,7 +442,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteAcl", params)
+            headers = request.headers
+            body = self.call("DeleteAcl", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteAclResponse()
@@ -316,7 +471,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteAclRule", params)
+            headers = request.headers
+            body = self.call("DeleteAclRule", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteAclRuleResponse()
@@ -334,6 +490,35 @@ class CkafkaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteGroup(self, request):
+        """删除消费组
+
+        :param request: Request instance for DeleteGroup.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.DeleteGroupRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.DeleteGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteGroup", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteGroupResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteInstancePre(self, request):
         """删除预付费实例
 
@@ -344,7 +529,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteInstancePre", params)
+            headers = request.headers
+            body = self.call("DeleteInstancePre", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteInstancePreResponse()
@@ -362,6 +548,35 @@ class CkafkaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteRoute(self, request):
+        """删除路由
+
+        :param request: Request instance for DeleteRoute.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.DeleteRouteRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.DeleteRouteResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteRoute", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteRouteResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteRouteTriggerTime(self, request):
         """修改删除路由延迟触发时间
 
@@ -372,7 +587,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteRouteTriggerTime", params)
+            headers = request.headers
+            body = self.call("DeleteRouteTriggerTime", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteRouteTriggerTimeResponse()
@@ -400,7 +616,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteTopic", params)
+            headers = request.headers
+            body = self.call("DeleteTopic", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteTopicResponse()
@@ -428,7 +645,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteTopicIpWhiteList", params)
+            headers = request.headers
+            body = self.call("DeleteTopicIpWhiteList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteTopicIpWhiteListResponse()
@@ -456,7 +674,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteUser", params)
+            headers = request.headers
+            body = self.call("DeleteUser", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteUserResponse()
@@ -484,7 +703,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeACL", params)
+            headers = request.headers
+            body = self.call("DescribeACL", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeACLResponse()
@@ -512,7 +732,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAppInfo", params)
+            headers = request.headers
+            body = self.call("DescribeAppInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAppInfoResponse()
@@ -540,7 +761,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeCkafkaZone", params)
+            headers = request.headers
+            body = self.call("DescribeCkafkaZone", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeCkafkaZoneResponse()
@@ -568,7 +790,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeConsumerGroup", params)
+            headers = request.headers
+            body = self.call("DescribeConsumerGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeConsumerGroupResponse()
@@ -596,7 +819,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeGroup", params)
+            headers = request.headers
+            body = self.call("DescribeGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeGroupResponse()
@@ -624,7 +848,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeGroupInfo", params)
+            headers = request.headers
+            body = self.call("DescribeGroupInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeGroupInfoResponse()
@@ -652,7 +877,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeGroupOffsets", params)
+            headers = request.headers
+            body = self.call("DescribeGroupOffsets", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeGroupOffsetsResponse()
@@ -680,7 +906,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeInstanceAttributes", params)
+            headers = request.headers
+            body = self.call("DescribeInstanceAttributes", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeInstanceAttributesResponse()
@@ -708,7 +935,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeInstances", params)
+            headers = request.headers
+            body = self.call("DescribeInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeInstancesResponse()
@@ -736,7 +964,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeInstancesDetail", params)
+            headers = request.headers
+            body = self.call("DescribeInstancesDetail", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeInstancesDetailResponse()
@@ -764,7 +993,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRegion", params)
+            headers = request.headers
+            body = self.call("DescribeRegion", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRegionResponse()
@@ -792,7 +1022,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRoute", params)
+            headers = request.headers
+            body = self.call("DescribeRoute", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRouteResponse()
@@ -821,7 +1052,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTopic", params)
+            headers = request.headers
+            body = self.call("DescribeTopic", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTopicResponse()
@@ -849,7 +1081,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTopicAttributes", params)
+            headers = request.headers
+            body = self.call("DescribeTopicAttributes", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTopicAttributesResponse()
@@ -877,7 +1110,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTopicDetail", params)
+            headers = request.headers
+            body = self.call("DescribeTopicDetail", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTopicDetailResponse()
@@ -905,7 +1139,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTopicSubscribeGroup", params)
+            headers = request.headers
+            body = self.call("DescribeTopicSubscribeGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTopicSubscribeGroupResponse()
@@ -933,7 +1168,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTopicSyncReplica", params)
+            headers = request.headers
+            body = self.call("DescribeTopicSyncReplica", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTopicSyncReplicaResponse()
@@ -961,7 +1197,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeUser", params)
+            headers = request.headers
+            body = self.call("DescribeUser", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeUserResponse()
@@ -989,7 +1226,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("FetchMessageByOffset", params)
+            headers = request.headers
+            body = self.call("FetchMessageByOffset", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.FetchMessageByOffsetResponse()
@@ -1017,7 +1255,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyGroupOffsets", params)
+            headers = request.headers
+            body = self.call("ModifyGroupOffsets", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyGroupOffsetsResponse()
@@ -1045,7 +1284,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyInstanceAttributes", params)
+            headers = request.headers
+            body = self.call("ModifyInstanceAttributes", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyInstanceAttributesResponse()
@@ -1073,7 +1313,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyPassword", params)
+            headers = request.headers
+            body = self.call("ModifyPassword", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyPasswordResponse()
@@ -1101,7 +1342,8 @@ class CkafkaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyTopicAttributes", params)
+            headers = request.headers
+            body = self.call("ModifyTopicAttributes", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyTopicAttributesResponse()
@@ -1112,6 +1354,35 @@ class CkafkaClient(AbstractClient):
                 message = response["Response"]["Error"]["Message"]
                 reqid = response["Response"]["RequestId"]
                 raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def SendMessage(self, request):
+        """通过HTTP接入层发送消息
+
+        :param request: Request instance for SendMessage.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.SendMessageRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.SendMessageResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("SendMessage", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.SendMessageResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
